==> zio-aws-docdb_2.13-5.17.295.14-sources.jar: zio/aws/docdb/model/CreateEventSubscriptionRequest.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.docdb.model.primitives.BooleanOptional
import scala.jdk.CollectionConverters._
final case class CreateEventSubscriptionRequest(
    subscriptionName: String,
    snsTopicArn: String,
    sourceType: Optional[String] = Optional.Absent,
    eventCategories: Optional[Iterable[String]] = Optional.Absent,
    sourceIds: Optional[Iterable[String]] = Optional.Absent,
    enabled: Optional[BooleanOptional] = Optional.Absent,
    tags: Optional[Iterable[zio.aws.docdb.model.Tag]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.CreateEventSubscriptionRequest = {
    import CreateEventSubscriptionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.CreateEventSubscriptionRequest
      .builder()
      .subscriptionName(subscriptionName: java.lang.String)
      .snsTopicArn(snsTopicArn: java.lang.String)
      .optionallyWith(sourceType.map(value => value: java.lang.String))(
        _.sourceType
      )
      .optionallyWith(
        eventCategories.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.eventCategories)
      .optionallyWith(
        sourceIds.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.sourceIds)
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.CreateEventSubscriptionRequest.ReadOnly =
    zio.aws.docdb.model.CreateEventSubscriptionRequest.wrap(buildAwsValue())
}
object CreateEventSubscriptionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.CreateEventSubscriptionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.CreateEventSubscriptionRequest =
      zio.aws.docdb.model.CreateEventSubscriptionRequest(
        subscriptionName,
        snsTopicArn,
        sourceType.map(value => value),
        eventCategories.map(value => value),
        sourceIds.map(value => value),
        enabled.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def subscriptionName: String
    def snsTopicArn: String
    def sourceType: Optional[String]
    def eventCategories: Optional[List[String]]
    def sourceIds: Optional[List[String]]
    def enabled: Optional[BooleanOptional]
    def tags: Optional[List[zio.aws.docdb.model.Tag.ReadOnly]]
    def getSubscriptionName: ZIO[Any, Nothing, String] =
      ZIO.succeed(subscriptionName)
    def getSnsTopicArn: ZIO[Any, Nothing, String] = ZIO.succeed(snsTopicArn)
    def getSourceType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("sourceType", sourceType)
    def getEventCategories: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("eventCategories", eventCategories)
    def getSourceIds: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("sourceIds", sourceIds)
    def getEnabled: ZIO[Any, AwsError, BooleanOptional] =
      AwsError.unwrapOptionField("enabled", enabled)
    def getTags: ZIO[Any, AwsError, List[zio.aws.docdb.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.CreateEventSubscriptionRequest
  ) extends zio.aws.docdb.model.CreateEventSubscriptionRequest.ReadOnly {
    override val subscriptionName: String = impl.subscriptionName(): String
    override val snsTopicArn: String = impl.snsTopicArn(): String
    override val sourceType: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.sourceType())
      .map(value => value: String)
    override val eventCategories: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.eventCategories())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val sourceIds: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.sourceIds())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val enabled: Optional[BooleanOptional] = zio.aws.core.internal
      .optionalFromNullable(impl.enabled())
      .map(value => value: BooleanOptional)
    override val tags: Optional[List[zio.aws.docdb.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.docdb.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.CreateEventSubscriptionRequest
  ): zio.aws.docdb.model.CreateEventSubscriptionRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-docdb_3-5.17.224.3-sources.jar: zio/aws/docdb/model/CreateEventSubscriptionRequest.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.docdb.model.primitives.BooleanOptional
import scala.jdk.CollectionConverters.*
final case class CreateEventSubscriptionRequest(
    subscriptionName: String,
    snsTopicArn: String,
    sourceType: Optional[String] = Optional.Absent,
    eventCategories: Optional[Iterable[String]] = Optional.Absent,
    sourceIds: Optional[Iterable[String]] = Optional.Absent,
    enabled: Optional[BooleanOptional] = Optional.Absent,
    tags: Optional[Iterable[zio.aws.docdb.model.Tag]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.CreateEventSubscriptionRequest = {
    import CreateEventSubscriptionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.CreateEventSubscriptionRequest
      .builder()
      .subscriptionName(subscriptionName: java.lang.String)
      .snsTopicArn(snsTopicArn: java.lang.String)
      .optionallyWith(sourceType.map(value => value: java.lang.String))(
        _.sourceType
      )
      .optionallyWith(
        eventCategories.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.eventCategories)
      .optionallyWith(
        sourceIds.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.sourceIds)
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.CreateEventSubscriptionRequest.ReadOnly =
    zio.aws.docdb.model.CreateEventSubscriptionRequest.wrap(buildAwsValue())
}
object CreateEventSubscriptionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.CreateEventSubscriptionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.CreateEventSubscriptionRequest =
      zio.aws.docdb.model.CreateEventSubscriptionRequest(
        subscriptionName,
        snsTopicArn,
        sourceType.map(value => value),
        eventCategories.map(value => value),
        sourceIds.map(value => value),
        enabled.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def subscriptionName: String
    def snsTopicArn: String
    def sourceType: Optional[String]
    def eventCategories: Optional[List[String]]
    def sourceIds: Optional[List[String]]
    def enabled: Optional[BooleanOptional]
    def tags: Optional[List[zio.aws.docdb.model.Tag.ReadOnly]]
    def getSubscriptionName: ZIO[Any, Nothing, String] =
      ZIO.succeed(subscriptionName)
    def getSnsTopicArn: ZIO[Any, Nothing, String] = ZIO.succeed(snsTopicArn)
    def getSourceType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("sourceType", sourceType)
    def getEventCategories: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("eventCategories", eventCategories)
    def getSourceIds: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("sourceIds", sourceIds)
    def getEnabled: ZIO[Any, AwsError, BooleanOptional] =
      AwsError.unwrapOptionField("enabled", enabled)
    def getTags: ZIO[Any, AwsError, List[zio.aws.docdb.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.CreateEventSubscriptionRequest
  ) extends zio.aws.docdb.model.CreateEventSubscriptionRequest.ReadOnly {
    override val subscriptionName: String = impl.subscriptionName(): String
    override val snsTopicArn: String = impl.snsTopicArn(): String
    override val sourceType: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.sourceType())
      .map(value => value: String)
    override val eventCategories: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.eventCategories())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val sourceIds: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.sourceIds())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val enabled: Optional[BooleanOptional] = zio.aws.core.internal
      .optionalFromNullable(impl.enabled())
      .map(value => value: BooleanOptional)
    override val tags: Optional[List[zio.aws.docdb.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.docdb.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.CreateEventSubscriptionRequest
  ): zio.aws.docdb.model.CreateEventSubscriptionRequest.ReadOnly = new Wrapper(
    impl
  )
}
